@@ -225,40 +225,35 @@ def get_option_parser():
 			"If LENGTH is positive, remove bases from the beginning. "
 			"If LENGTH is negative, remove bases from the end. "
 			"Can be used twice if LENGTHs have different signs.")
+	group.add_option("--nextseq-trim", type=int, default=None, metavar="3'CUTOFF",
+		help="NextSeq-specific quality trimming (each read). Trims also dark "
+			"cycles appearing as high-quality G bases (EXPERIMENTAL).")
 	group.add_option("-q", "--quality-cutoff", default=None, metavar="[5'CUTOFF,]3'CUTOFF",
 		help="Trim low-quality bases from 5' and/or 3' ends of each read before "
 			"adapter removal. Applied to both reads if data is paired. If one "
 			"value is given, only the 3' end is trimmed. If two "
 			"comma-separated cutoffs are given, the 5' end is trimmed with "
 			"the first cutoff, the 3' end with the second.")
-	group.add_option("--nextseq-trim", type=int, default=None, metavar="3'CUTOFF",
-		help="NextSeq-specific quality trimming (each read). Trims also dark "
-			"cycles appearing as high-quality G bases (EXPERIMENTAL).")
 	group.add_option("--quality-base", type=int, default=33,
 		help="Assume that quality values in FASTQ are encoded as ascii(quality "
 			"+ QUALITY_BASE). This needs to be set to 64 for some old Illumina "
 			"FASTQ files. Default: %default")
 	group.add_option("--trim-n", action='store_true', default=False,
 		help="Trim N's on ends of reads.")
-	group.add_option("-x", "--prefix", default='',
-		help="Add this prefix to read names. Use {name} to insert the name of the matching adapter.")
-	group.add_option("-y", "--suffix", default='',
-		help="Add this suffix to read names; can also include {name}")
-	group.add_option("--strip-suffix", action='append', default=[],
-		help="Remove this suffix from read names if present. Can be given multiple times.")
 	group.add_option("--length-tag", metavar="TAG",
 		help="Search for TAG followed by a decimal number in the description "
 			"field of the read. Replace the decimal number with the correct "
 			"length of the trimmed read. For example, use --length-tag 'length=' "
 			"to correct fields like 'length=123'.")
+	group.add_option("--strip-suffix", action='append', default=[],
+		help="Remove this suffix from read names if present. Can be given multiple times.")
+	group.add_option("-x", "--prefix", default='',
+		help="Add this prefix to read names. Use {name} to insert the name of the matching adapter.")
+	group.add_option("-y", "--suffix", default='',
+		help="Add this suffix to read names; can also include {name}")
 	parser.add_option_group(group)
 
 	group = OptionGroup(parser, "Filtering of processed reads")
-	group.add_option("--discard-trimmed", "--discard", action='store_true', default=False,
-		help="Discard reads that contain an adapter. Also use -O to avoid "
-			"discarding too many randomly matching reads!")
-	group.add_option("--discard-untrimmed", "--trimmed-only", action='store_true', default=False,
-		help="Discard reads that do not contain the adapter.")
 	group.add_option("-m", "--minimum-length", type=int, default=0, metavar="LENGTH",
 		help="Discard trimmed reads that are shorter than LENGTH. Reads that "
 			"are too short even before adapter removal are also discarded. In "
@@ -272,6 +267,11 @@ def get_option_parser():
 		help="Discard reads with too many N bases. If COUNT is an integer, it "
 			"is treated as the absolute number of N bases. If it is between 0 "
 			"and 1, it is treated as the proportion of N's allowed in a read.")
+	group.add_option("--discard-trimmed", "--discard", action='store_true', default=False,
+		help="Discard reads that contain an adapter. Also use -O to avoid "
+			"discarding too many randomly matching reads!")
+	group.add_option("--discard-untrimmed", "--trimmed-only", action='store_true', default=False,
+		help="Discard reads that do not contain the adapter.")
 	parser.add_option_group(group)
 
 	group = OptionGroup(parser, "Output")
@@ -399,44 +399,51 @@ def main(cmdlineargs=None, default_outfile=sys.stdout):
 		paired = 'first'
 	# Any of these options switch off legacy mode
 	if (options.adapters2 or options.front2 or options.anywhere2 or
-		options.cut2 or options.interleaved or options.pair_filter or
-		options.too_short_paired_output or options.too_long_paired_output):
+			options.cut2 or options.interleaved or options.pair_filter or
+			options.too_short_paired_output or options.too_long_paired_output):
 		# Full paired-end trimming when both -p and -A/-G/-B/-U given
 		# Read modifications (such as quality trimming) are applied also to second read.
 		paired = 'both'
 
 	if paired and len(args) == 1 and not options.interleaved:
-		parser.error("When paired-end trimming is enabled via -A/-G/-B/-U or -p, "
-			"two input files are required.")
-	if options.interleaved and len(args) != 1:
-		parser.error("When reading interleaved files, only one input file may "
-			"be given.")
+		parser.error("When paired-end trimming is enabled via -A/-G/-B/-U/"
+			"--interleaved or -p, two input files are required.")
 	if not paired:
 		if options.untrimmed_paired_output:
 			parser.error("Option --untrimmed-paired-output can only be used when "
 				"trimming paired-end reads (with option -p).")
 
+	interleaved_input = False
+	interleaved_output = False
+	if options.interleaved:
+		interleaved_input = len(args) == 1
+		interleaved_output = not options.paired_output
+		if not interleaved_input and not interleaved_output:
+			parser.error("When --interleaved is used, you cannot provide both two input files and two output files")
+
 	# Assign input_paired_filename and quality_filename
 	input_paired_filename = None
 	quality_filename = None
 	if paired:
-		if not options.interleaved:
+		if not interleaved_input:
 			input_paired_filename = args[1]
+		if not interleaved_output:
 			if not options.paired_output:
 				parser.error("When paired-end trimming is enabled via -A/-G/-B/-U, "
 					"a second output file needs to be specified via -p (--paired-output).")
 			if not options.output:
 				parser.error("When you use -p or --paired-output, you must also "
 					"use the -o option.")
-			if bool(options.untrimmed_output) != bool(options.untrimmed_paired_output):
-				parser.error("When trimming paired-end reads, you must use either none "
-					"or both of the --untrimmed-output/--untrimmed-paired-output options.")
-			if options.too_short_output and not options.too_short_paired_output:
-				parser.error("When using --too-short-output with paired-end "
-					"reads, you also need to use --too-short-paired-output")
-			if options.too_long_output and not options.too_long_paired_output:
-				parser.error("When using --too-long-output with paired-end "
-					"reads, you also need to use --too-long-paired-output")
+
+		if bool(options.untrimmed_output) != bool(options.untrimmed_paired_output):
+			parser.error("When trimming paired-end reads, you must use either none "
+				"or both of the --untrimmed-output/--untrimmed-paired-output options.")
+		if options.too_short_output and not options.too_short_paired_output:
+			parser.error("When using --too-short-output with paired-end "
+				"reads, you also need to use --too-short-paired-output")
+		if options.too_long_output and not options.too_long_paired_output:
+			parser.error("When using --too-long-output with paired-end "
+				"reads, you also need to use --too-long-paired-output")
 	elif len(args) == 2:
 		quality_filename = args[1]
 		if options.format is not None:
@@ -450,7 +457,7 @@ def main(cmdlineargs=None, default_outfile=sys.stdout):
 	try:
 		reader = seqio.open(input_filename, file2=input_paired_filename,
 				qualfile=quality_filename, colorspace=options.colorspace,
-				fileformat=options.format, interleaved=options.interleaved)
+				fileformat=options.format, interleaved=interleaved_input)
 	except (seqio.UnknownFileType, IOError) as e:
 		parser.error(e)
 
@@ -472,8 +479,7 @@ def main(cmdlineargs=None, default_outfile=sys.stdout):
 		cutoffs = None
 
 	open_writer = functools.partial(seqio.open, mode='w',
-		qualities=reader.delivers_qualities, colorspace=options.colorspace,
-		interleaved=options.interleaved)
+		qualities=reader.delivers_qualities, colorspace=options.colorspace)
 
 	if options.pair_filter is None:
 		options.pair_filter = 'any'
@@ -536,9 +542,9 @@ def main(cmdlineargs=None, default_outfile=sys.stdout):
 		# Finally, figure out where the reads that passed all the previous
 		# filters should go.
 		if options.output is not None:
-			writer = open_writer(options.output, options.paired_output)
+			writer = open_writer(options.output, options.paired_output, interleaved=interleaved_output)
 		else:
-			writer = open_writer(default_outfile)
+			writer = open_writer(default_outfile, interleaved=interleaved_output)
 		if not paired:
 			filters.append(NoFilter(writer))
 		else:
